@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python3
 
 import os
 from depp import Model_pl
@@ -13,8 +13,8 @@ from pytorch_lightning.loggers import TensorBoardLogger
 from omegaconf import OmegaConf
 
 
-os.environ['OMP_NUM_THREADS'] = '1'
-os.environ['MKL_NUM_THREADS'] = '1'
+#os.environ['OMP_NUM_THREADS'] = '1'
+#os.environ['MKL_NUM_THREADS'] = '1'
 
 def main():
     args_base = OmegaConf.create(default_config.default_config)
@@ -31,21 +31,10 @@ def main():
     args = OmegaConf.merge(args_base, args_cli)
 
     model_dir = args.model_dir
-    if not os.path.isdir(model_dir):
-        os.makedirs(model_dir)
-
-    summary_dir = args.summary_dir
-
-    if not os.path.isdir(summary_dir):
-        os.makedirs(summary_dir)
+    os.makedirs(model_dir, exist_ok=True)
 
     model = Model_pl.model(args=args)
 
-    logger = TensorBoardLogger(
-        save_dir=args.summary_dir,
-        name=args.exp_name
-    )
-
     early_stop_callback = EarlyStopping(
         monitor='val_loss',
         min_delta=0.00,
@@ -65,7 +54,7 @@ def main():
     print(model_dir)
     if args.gpus == 0:
         trainer = pl.Trainer(
-            logger=logger,
+            logger=False,
             gpus=args.gpus,
             progress_bar_refresh_rate=args.bar_update_freq,
             check_val_every_n_epoch=args.val_freq,
@@ -77,7 +66,7 @@ def main():
         )
     else:
         trainer = pl.Trainer(
-            logger=logger,
+            logger=False,
             gpus=args.gpus,
             progress_bar_refresh_rate=args.bar_update_freq,
             distributed_backend='ddp',
